@@ -12,28 +12,49 @@ use warp::reject::not_found;
 use warp::reply::{html, Reply};
 use warp::Filter;
 
+use crate::certificate::new_certificate;
 use crate::port::next_port_in_range;
 
-pub async fn run(folder: String, ip: [u8; 4], port: u16, footer: String) -> io::Result<()> {
+pub async fn run(
+    folder: String,
+    ip: [u8; 4],
+    footer: String,
+    port: Option<u16>,
+    has_tls: bool,
+) -> io::Result<()> {
     let ip_addr = IpAddr::from(ip);
+    let port = match port {
+        Some(p) => p,
+        None => next_port_in_range(8080..9000).expect("Cannot open any port in requested range."),
+    };
     let socket_addr = SocketAddr::from((ip_addr, port));
-    let handle = tokio::spawn(warp::serve(routes(folder, footer)).bind(socket_addr));
-    ctrl_c().await?;
-    handle.abort();
-    handle.await?;
-    Ok(())
-}
 
-pub async fn run_auto_port(folder: String, ip: [u8; 4], footer: String) -> io::Result<()> {
-    let ip_addr = IpAddr::from(ip);
-    let port = next_port_in_range(8080..9000).expect("Cannot open any port in requested range.");
-    let socket_addr = SocketAddr::from((ip_addr, port));
-    let handle = tokio::spawn(warp::serve(routes(folder, footer)).bind(socket_addr));
-    println!(
-        "Serving on: http://{}:{}",
-        local_ipaddress::get().unwrap(),
-        port
-    );
+    new_certificate(local_ipaddress::get().unwrap(), port);
+    let handle = match has_tls {
+        true => tokio::spawn(
+            warp::serve(routes(folder, footer))
+                .tls()
+                .cert_path("/tmp/warpy.pem")
+                .key_path("/tmp/warpy.key")
+                .bind(socket_addr),
+        ),
+        false => tokio::spawn(warp::serve(routes(folder, footer)).bind(socket_addr)),
+    };
+
+    if has_tls {
+        println!(
+            "Serving on: https://{}:{}",
+            local_ipaddress::get().unwrap(),
+            port
+        );
+    } else {
+        println!(
+            "Serving on: http://{}:{}",
+            local_ipaddress::get().unwrap(),
+            port
+        );
+    }
+
     ctrl_c().await?;
     handle.abort();
     handle.await?;
